@@ -4,8 +4,9 @@ QStringList current_config=QStringList();
 QString current_core="";
 options::options(QWidget *parent) :    QWidget(parent)
 {
-
+	#ifdef Q_WS_MAEMO_5
     this->setAttribute(Qt::WA_Maemo5StackedWindow);
+	#endif
     this->setWindowFlags(this->windowFlags() | Qt::Window);
     QVBoxLayout *lay2=new QVBoxLayout(this);
 
